(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     18417,        472]*)
(*NotebookOutlinePosition[     44774,       1427]*)
(*  CellTagsIndexPosition[     44730,       1423]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["\n3D-Turtle\nInterpretation\n",
  FontFamily->"Times",
  FontColor->RGBColor[0.608011, 0.0997024, 0.477028]]], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Principia Evolvica",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox["\n\n",
    FontFamily->"Times"],
  StyleBox["Christian Jacob",
    FontFamily->"Times",
    FontSize->17],
  StyleBox["",
    FontFamily->"Times"]
}], "Subtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"\ndpunkt.Verlag, Heidelberg\n\nJanuar 1997\n\n\[Copyright] Copyright\n"], 
  "Subsubtitle",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Einf\[UDoubleDot]hrung"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Dieses Notebook enth\[ADoubleDot]lt die grunds\[ADoubleDot]tzlichen \
Definitionen zur Turtle-Interpretation von Ausdr\[UDoubleDot]cken, die durch \
L-Systeme generiert wurden. Die Turtle-Befehle sind in ",
    FontFamily->"Times"],
  StyleBox["Principia Evolvica",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", Kapitel 11.2.3 ausf\[UDoubleDot]hrlich beschrieben.",
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["3D-Turtle-Interpretation"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Optionen"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Options[turtleInterpretation] :=\n{\n  Iterations -> 1,\n  StartPosition \
-> {0.,0.,0.},\n  StartDirection -> Transpose[{{0,0,1},{1,0,0},{0,-1,0}}],\n  \
\n  GravityDirection -> {0.,0.,-1.},\n  \n  StepVariance -> 0.,\n  \
AngleVariance -> 0.,\n  LineThickness -> 0.014,\n  LineHue -> 0.3,\n  \n  \
MaxNumberOfPaths -> 400,\n  MaxPathLength -> 200,\n  \n  InterpretationTable \
->\n    {\n      AXIOM -> List,\n      \n      FO -> forward,\n      BA -> \
back,\n      \n      YL -> yawLeft,\n      YR -> yawRight,\n      \n      PD \
-> pitchDown,\n      PU -> pitchUp,\n      \n      RL -> rollLeft,\n      RR \
-> rollRight,\n      \n      RV -> orientateToVertical,\n      \n      TN -> \
turnAround,\n      \n      JF -> jumpForward,\n      JB -> jumpBack,\n      \
JU -> jumpUp,\n      JD -> jumpDown,\n      \n      N  -> north,\n      E  -> \
east,\n      S  -> south,\n\t     W  -> west,\n\t     \n\t     DP -> \
drawPoint,\n\t     DPLY -> drawPolygon,\n\n      STACK[x___] :> {push,x,pop},\
\n      SEQ[x___] :> {x},\n      \n      POLYGON[x___] :> \
({resetPolygonPoints[],setPolygonPoint[],\n                         x,\n      \
                   constructPolygon[]} /. JF[s_] :> \
{JF[s],setPolygonPoint[]}),\n      \n      CO[c_] :> setColor[c],\n      \
CI[c_] :> incrementColor[c],\n      CD[c_] :> decrementColor[c],\n      \n    \
  \n      TH[c_] :> setThickness[c],\n      TI[c_] :> incrementThickness[c],\n\
      TD[c_] :> decrementThickness[c],\n      TS[c_] :> scaleThickness[c]\n   \
  },\n     \n   GraphicOptions ->\n   {\n     AspectRatio -> 1,\n\t    Axes \
-> True,\n\t    Boxed -> True,\n\t",
  StyleBox["        (**",
    FontFamily->"Times"],
  "ViewPoint->{-2.644, -0.679, 2.000},**)\n\t    (**PlotRange -> \
{{-6,0},{-5,4},{0,6}},**)\n\t    PlotRange -> All,\n\t    Background -> \
GrayLevel[.9],",
  StyleBox["\n    ",
    FontFamily->"Times"],
  "   DisplayFunction -> $DisplayFunction\n   }\n\t \n};\n"
}], "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Interpretationsfunktion"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "turtleInterpretation[turtleExpr_, opts___] :=\nModule[\n\t{  \n\t  dim1 = \
MaxPathLength /. {opts} /. Options[turtleInterpretation],\n    dim2 = \
MaxNumberOfPaths /. {opts} /. Options[turtleInterpretation],\n    \n    X = \
N[StartPosition /. {opts} /. Options[turtleInterpretation] ], \n    U = \
N[StartDirection /. {opts} /. Options[turtleInterpretation] ], \n    \n    \
gravityDirection = GravityDirection /. {opts} /. \
Options[turtleInterpretation],\n    \n    interpretationTable = \n\t    \
InterpretationTable /. {opts} /. Options[turtleInterpretation],\n\n    \
currentColor = (LineHue /. {opts} /. Options[turtleInterpretation]),\n    \n  \
  stepVariance = StepVariance /. {opts} /. Options[turtleInterpretation],\n   \
 angleVariance = AngleVariance /. {opts} /. Options[turtleInterpretation],\n  \
  thickN = LineThickness /. {opts} /. Options[turtleInterpretation],\n\n    \
yawMatrix, pitchMatrix, rollMatrix,\n\n\t   i = 1, count = {1}, sV,aV, \
polygonPoints = {},\n\t   turtleStack = {},\n  },\n  \n",
  StyleBox["  (* --- Defining a list for entering paths --------- *)\n",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.666651]],
  "  \n  paths = Table[Null,{dim2}];\n  paths[[1]] = \n    \
Graphics3D[{GrayLevel[1.], PointSize[.02], Point[X]}];\n\n",
  StyleBox["  (* --- Setting step and angle variance ------------ *)\n",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.666651]],
  "  \n  sV := 1. + Random[Real,{-stepVariance,stepVariance}];\n  aV := 1. + \
Random[Real,{-angleVariance,angleVariance}];\n  \n  \n",
  StyleBox["  (* --- Turtle INTERPRETATION ----------------------- *)\n",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.666651]],
  "  \n",
  StyleBox["  (* --- Attributes of the turtle function ----------- *)\n",
    FontSlant->"Italic"],
  "  \n  Attributes[turtle] = Listable;\n\n  \n",
  StyleBox["  (* --- Moving back and forth ----------------------- *)\n",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.666651]],
  StyleBox[" ",
    FontColor->GrayLevel[0.666651]],
  " \n  turtle[",
  StyleBox["forward",
    FontColor->RGBColor[0, 0, 1]],
  "[s_]] := paths[[++i]] \n    = Graphics3D[{Thickness[thickN], (* 2. *)\n    \
              Hue[currentColor],\n                  Line[{X,X += s sV \
First[Transpose@U]}]}];\n  turtle[",
  StyleBox["back",
    FontColor->RGBColor[0, 0, 1]],
  "[s_]]    := paths[[++i]] \n    = Graphics3D[{Thickness[thickN], (* 1. *)\n \
                 Hue[currentColor],\n                  Line[{X,X -= s sV \
First[Transpose@U]}]}];\n  \n",
  StyleBox["  (* --- Jumping back, forth, up, and down ----------- *)\n",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.666651]],
  "  \n  turtle[",
  StyleBox["jumpForward",
    FontColor->RGBColor[0, 0, 1]],
  "[s_]] := X += s sV First[Transpose@U];\n  \n  turtle[",
  StyleBox["jumpBack",
    FontColor->RGBColor[0, 0, 1]],
  "[s_]] := X -= s sV First[Transpose@U];\n  \n  turtle[",
  StyleBox["jumpUp",
    FontColor->RGBColor[0, 0, 1]],
  "[s_]] := \n    (U = U.pitchMatrix[ 90 aV Degree] // N; (* pitch up *)\n    \
 X += s sV First[Transpose@U]; (* forward *)\n     U = U.pitchMatrix[-90 aV \
Degree] // N; (* pitch down *)\n    );\n    \n  turtle[",
  StyleBox["jumpDown",
    FontColor->RGBColor[0, 0, 1]],
  "[s_]] := \n    (U = U.pitchMatrix[-90 aV Degree] // N; (* pitch up *)\n    \
 X += s sV First[Transpose@U]; (* forward *)\n     U = U.pitchMatrix[ 90 aV \
Degree] // N; (* pitch down *)\n    );\n    \n",
  StyleBox["  (* --- Drawing polygons and ------------------------ *)\n",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.666651]],
  "  \n  turtle[",
  StyleBox["resetPolygonPoints",
    FontColor->RGBColor[0, 0, 1]],
  "[]] := (polygonPoints = {});\n  turtle[",
  StyleBox["setPolygonPoint",
    FontColor->RGBColor[0, 0, 1]],
  "[]] := (AppendTo[polygonPoints,X]);\n  \n  turtle[",
  StyleBox["constructPolygon",
    FontColor->RGBColor[0, 0, 1]],
  "[]] := paths[[++i]]\n    = Graphics3D[{Polygon[polygonPoints]}];\n\n  \
turtle[",
  StyleBox["drawPolygon",
    FontColor->RGBColor[0, 0, 1]],
  "[s_,c_,polyCoords_]] := \n    paths[[++i]]\n    = Graphics3D[{\n           \
       Hue[c],\n                  Polygon[Map[s (X+#)&, polyCoords]]}];\n    \
\n",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox[" (* --- Drawing points ------------------------------ *)\n",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.666651]],
  "  \n  turtle[",
  StyleBox["drawPoint",
    FontColor->RGBColor[0, 0, 1]],
  "[s_,c_]] := paths[[++i]] \n    = Graphics3D[{PointSize[.01 s],\n           \
       Hue[c],\n                  Point[X]}];\n  \n",
  StyleBox["  (* --- Specials for plants ------------------------- *)\n",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.666651]],
  "         \n  turtle[",
  StyleBox["BLOOM",
    FontColor->RGBColor[0, 0, 1]],
  "[b_,s_]] := paths[[++i]] \n    = TranslateShape[\n        AffineShape[\n   \
       ListSurfaceOfRevolution[\n            b,\n            RevolutionAxis \
-> First[Transpose@U],\n            DisplayFunction -> Identity],\n          \
{s,s,s}\n        ],\n        X];\n  \n",
  StyleBox["  (* --- A wrapper for translating and scaling ------- *)\n",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.666651]],
  "  \n  turtle[",
  StyleBox["GRAPHICS",
    FontColor->RGBColor[0, 0, 1]],
  "[g_,s_]] := paths[[++i]] \n    = TranslateShape[AffineShape[g,{s,s,s}],X];\
\n\n",
  StyleBox["  (* --- Rotations: ---------------------------------- *)\n",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.666651]],
  "  \n",
  StyleBox["  (* --- Yawing around the vertical axis ------------- *)\n",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.666651]],
  "  \n  turtle[",
  StyleBox["yawLeft",
    FontColor->RGBColor[0, 0, 1]],
  "[a_]]   := U = U.yawMatrix[-a aV Degree] // N;\n  turtle[",
  StyleBox["yawRight",
    FontColor->RGBColor[0, 0, 1]],
  "[a_]]  := U = U.yawMatrix[ a aV Degree] // N;\n  \n",
  StyleBox["  (* --- Pitching around the horizontal axis --------- *)\n",
    FontSlant->"Italic"],
  "  \n  turtle[",
  StyleBox["pitchDown",
    FontColor->RGBColor[0, 0, 1]],
  "[a_]] := U = U.pitchMatrix[-a aV Degree] // N;\n  turtle[",
  StyleBox["pitchUp",
    FontColor->RGBColor[0, 0, 1]],
  "[a_]]   := U = U.pitchMatrix[ a aV Degree] // N;\n \n",
  StyleBox["  (* --- Rolling around the longitudinal axis -------- *)\n",
    FontSlant->"Italic"],
  "  \n  turtle[",
  StyleBox["rollLeft",
    FontColor->RGBColor[0, 0, 1]],
  "[a_]]  := U = U.rollMatrix[-a aV Degree] // N;\n  turtle[",
  StyleBox["rollRight",
    FontColor->RGBColor[0, 0, 1]],
  "[a_]] := U = U.rollMatrix[ a aV Degree] // N;\n  \n",
  StyleBox[
  "  (* --- Rotate turtle to vertical (p.57)------------- *)\n  (* --- l is \
the turtle lefthand side vector          *)\n  (* --- v is the direction \
opposite to gravity        *)\n  (* --- h is the turtle heading vector        \
        *)\n  (* --- u is the turtle up vector                     *)\n",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.666651]],
  "  \n  turtle[",
  StyleBox["orientateToVertical",
    FontColor->RGBColor[0, 0, 1]],
  "[]]  := Module[{l,v,h,u},\n  \n    v = -gravityDirection;\n    h = \
Transpose[U][[1]];\n    l = vectorProduct[v,h];\n    l = l/norm[l];\n    u = \
vectorProduct[h,l];\n    \n    U = Transpose[{h,l,u}]\n  ]; \n\n",
  StyleBox["  (* --- Turning around ------------------------------ *)\n",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.666651]],
  "  \n  turtle[",
  StyleBox["turnAround",
    FontColor->RGBColor[0, 0, 1]],
  "[]]  := U = U.yawMatrix[180 Degree] // N;\n  turtle[",
  StyleBox["turnAround",
    FontColor->RGBColor[0, 0, 1]],
  "  ]  := U = U.yawMatrix[180 Degree] // N;\n  \n",
  StyleBox["  (* --- Color settings ------------------------------ *)\n",
    FontSlant->"Italic"],
  "  \n  turtle[",
  StyleBox["setColor",
    FontColor->RGBColor[0, 0, 1]],
  "[c_]]  := (currentColor = c);\n  \n  turtle[",
  StyleBox["incrementColor",
    FontColor->RGBColor[0, 0, 1]],
  "[c_]]  := \n    (currentColor += c; currentColor = Mod[currentColor,1]);\n \
 turtle[",
  StyleBox["decrementColor",
    FontColor->RGBColor[0, 0, 1]],
  "[c_]]  := \n    (currentColor -= c; currentColor = Mod[currentColor,1]);\n \
 \n",
  StyleBox["  (* --- Line thickness settings --------------------- *)\n",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.666651]],
  "    \n  turtle[",
  StyleBox["setThickness",
    FontColor->RGBColor[0, 0, 1]],
  "[c_]]  := (thickN = c);\n  turtle[",
  StyleBox["scaleThickness",
    FontColor->RGBColor[0, 0, 1]],
  "[c_]]  := \n    (thickN *= c; thickN = Mod[thickN,1]);\n  \n  turtle[",
  StyleBox["incrementThickness",
    FontColor->RGBColor[0, 0, 1]],
  "[c_]]  := \n    (thickN += c; thickN = Mod[thickN,1]);\n  turtle[",
  StyleBox["decrementThickness",
    FontColor->RGBColor[0, 0, 1]],
  "[c_]]  := \n    (thickN -= c; thickN = Mod[thickN,1]);\n  \n",
  StyleBox["  (* --- Stacking ------------------------------------ *)\n",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.666651]],
  "  \n  turtle[",
  StyleBox["push",
    FontColor->RGBColor[0, 0, 1]],
  "]    := PrependTo[turtleStack, {X,U}];\n\n  turtle[",
  StyleBox["pop",
    FontColor->RGBColor[0, 0, 1]],
  "]     := ({X,U} = First[turtleStack]; \n                      \
(**paths[[++i]] = X; **)\n                      turtleStack = \
Rest[turtleStack]);\n\n\t\t\t\t\n",
  StyleBox["  (* --- Rotation matrices --------------------------- *)\n",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.666651]],
  "  \n  yawMatrix[a_]   := {{ Cos[a], Sin[a], 0     },\n                     \
 {-Sin[a], Cos[a], 0     },\n                      { 0     , 0     , 1     \
}};\n                               \n  pitchMatrix[a_] := {{ Cos[a], 0     \
,-Sin[a]},\n                      { 0     , 1     , 0     },\n                \
      { Sin[a], 0     , Cos[a]}};\n  \n  rollMatrix[a_]  := {{ 1     , 0     \
, 0     },\n                      { 0     , Cos[a],-Sin[a]},\n                \
      { 0     , Sin[a], Cos[a]}};\n  \n\n",
  StyleBox[
  "  (* ------------------------------------------------- *)\n  (* --- now \
start the interpretation actions ... ---- *)\n  (* \
------------------------------------------------- *)\n",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.666651]],
  "\n  Print[\"Starting turtle interpretation ...\"];\n\n",
  StyleBox[" ",
    FontColor->GrayLevel[0.666651]],
  StyleBox[
  " (* turtleExpr is the parameter of the \n     turtleInterpretation \
function *)\n",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.666651]],
  "     \n  interpretationTime = \n    First[Timing[turtle[turtleExpr //. \
interpretationTable]]];\n    \n  Print[\"Time needed: \",interpretationTime];\
\n  \n  (**\n  paths = \n    Map[Drop[#,1]&,\n      Map[Take[paths[[#]], \
count[[#]]] &, Range[i]]\n    ] // Flatten; \n  **)\n  \n  paths = \
Take[paths,i];\n  \n",
  StyleBox[
  "  (* ------------------------------------------------- *)\n  (* --- \
Generating the graphics output -------------- *)\n  (* \
------------------------------------------------- *)\n",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.666651]],
  "  \n  Print[\"Generating graphics ...\"];\n  \n  turtlePlot = \n  Show[\n  \
  {paths},\n\t\t  GraphicOptions /. {opts} /. Options[turtleInterpretation]\n \
 ];\n  \n  turtlePlot\n  \n]; (* end module *)\n\t\t\t\t\t\t\t\t\t\t\t\t "
}], "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Berechnungen mit Vektoren"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Normalisierung eines Vektors"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["norm[v_] := N[Sqrt[v . v]]"], "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Orthonormales Koordinatensystem"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["e1 = {1,0,0};\ne2 = {0,1,0};\ne3 = {0,0,1};"], "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Vektor-Produkt"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"vectorProduct[u_,v_] :=\n N[{Det[{u,v,e1}],Det[{u,v,e2}],Det[{u,v,e3}]}]"], 
  "Input",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Referenzen"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["C. Jacob, ",
    FontFamily->"Times"],
  StyleBox["Principia Evolvica",
    FontFamily->"Times",
    FontSlant->"Italic"],
  StyleBox[", dpunkt.Verlag, Heidelberg, 1997, Kapitel 11.2.3",
    FontFamily->"Times"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 640}, {0, 460}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{632, 436},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{7, Inherited}, {8, 40}},
    Evaluatable->False,
    CellGroupingRules->{"TitleGrouping", 0},
    CellHorizontalScrolling->False,
    PageBreakBelow->False,
    GroupPageBreakWithin->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    AspectRatioFixed->True,
    FontFamily->"times",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.115999, 0.492988]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{7, Inherited}, {6, 15}},
    Evaluatable->False,
    CellGroupingRules->{"TitleGrouping", 10},
    CellHorizontalScrolling->False,
    PageBreakBelow->False,
    GroupPageBreakWithin->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    AspectRatioFixed->True,
    FontFamily->"times",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{7, Inherited}, {6, 20}},
    Evaluatable->False,
    CellGroupingRules->{"TitleGrouping", 20},
    CellHorizontalScrolling->False,
    PageBreakBelow->False,
    GroupPageBreakWithin->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    AspectRatioFixed->True,
    FontFamily->"times",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    Evaluatable->False,
    CellGroupingRules->{"SectionGrouping", 30},
    CellHorizontalScrolling->False,
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    AspectRatioFixed->True,
    FontFamily->"times",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{19, Inherited}, {8, 15}},
    Evaluatable->False,
    CellGroupingRules->{"SectionGrouping", 40},
    CellHorizontalScrolling->False,
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    AspectRatioFixed->True,
    FontFamily->"times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[EmptySquare]",
    CellMargins->{{18, Inherited}, {8, 12}},
    Evaluatable->False,
    CellGroupingRules->{"SectionGrouping", 50},
    CellHorizontalScrolling->False,
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    AspectRatioFixed->True,
    FontFamily->"times",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{7, 10}, {7, 7}},
    Evaluatable->False,
    CellHorizontalScrolling->False,
    PageBreakWithin->Automatic,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    AspectRatioFixed->True,
    FontFamily->"times",
    FontSize->12],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{7, 10}, {6, 6}},
    Evaluatable->False,
    CellHorizontalScrolling->False,
    PageBreakWithin->Automatic,
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    AspectRatioFixed->True,
    FontFamily->"times",
    FontSize->10],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    PageWidth->Infinity,
    CellFrame->True,
    CellMargins->{{42, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    AspectRatioFixed->True,
    FontFamily->"courier",
    FontSize->10,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    PageWidth->Infinity,
    CellMargins->{{42, 10}, {7, 5}},
    CellEditDuplicate->True,
    Evaluatable->False,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    LineSpacing->{1, 0},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    AspectRatioFixed->True,
    FontFamily->"courier",
    FontSize->10],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    PageWidth->Infinity,
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    AspectRatioFixed->True,
    StyleMenuListing->None,
    FontFamily->"courier",
    FontSize->12,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    PageWidth->Infinity,
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    AspectRatioFixed->True,
    StyleMenuListing->None,
    FontFamily->"courier",
    FontSize->12,
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    PageWidth->Infinity,
    CellMargins->{{7, Inherited}, {Inherited, Inherited}},
    Evaluatable->False,
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    AspectRatioFixed->True,
    ImageSize->{282, 287},
    ImageMargins->{{34, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"courier",
    FontSize->12],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{7, 0}, {4, 1}},
    Evaluatable->False,
    CellHorizontalScrolling->False,
    PageBreakWithin->Automatic,
    AspectRatioFixed->True,
    StyleMenuListing->None,
    FontFamily->"times",
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{7, 0}, {0, 4}},
    Evaluatable->False,
    CellHorizontalScrolling->False,
    PageBreakWithin->Automatic,
    TextAlignment->Center,
    AspectRatioFixed->True,
    StyleMenuListing->None,
    FontFamily->"times",
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->Primary,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00d0001804P000000dT2DP000003B@9Bm@05N`?N004000340<`000002?06T`3D
03@0I2/@02`00@4100000BL?00400@00000000000000000006@0000000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 191, 4, 156, "Title"],
Cell[1925, 57, 322, 13, 80, "Subtitle"],
Cell[2250, 72, 155, 4, 145, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2430, 80, 99, 2, 48, "Section"],
Cell[2532, 84, 500, 13, 47, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3069, 102, 101, 2, 48, "Section"],

Cell[CellGroupData[{
Cell[3195, 108, 88, 2, 40, "Subsection"],
Cell[3286, 112, 2027, 33, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[5350, 150, 103, 2, 29, "Subsection"],
Cell[5456, 154, 11523, 252, 70, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[17016, 411, 105, 2, 29, "Subsection"],

Cell[CellGroupData[{
Cell[17146, 417, 111, 2, 70, "Subsubsection"],
Cell[17260, 421, 107, 2, 70, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[17404, 428, 114, 2, 70, "Subsubsection"],
Cell[17521, 432, 124, 2, 70, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[17682, 439, 97, 2, 70, "Subsubsection"],
Cell[17782, 443, 157, 4, 70, "Input",
  InitializationCell->True]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18000, 454, 87, 2, 32, "Section"],
Cell[18090, 458, 299, 10, 31, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

